# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class MoneybirdLedgerAccount(UniversalBaseModel):
    """
    Moneybird ledger account (chart of accounts) - API format

    Attributes:
        rgs_code: Reference Grootboekschema (RGS) code - required for creation
        name: Account name
        account_type: Account type (revenue, expense, etc.)
        account_id: Account identifier (optional, system accounts may not have this)
    """

    rgs_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    RGS code - required for creation, not returned by GET API
    """

    name: str = pydantic.Field()
    """
    Account name
    """

    account_type: str = pydantic.Field()
    """
    Account type (revenue, expense, etc.)
    """

    account_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Account identifier (optional for system accounts)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .storage_bucket_lifecycle_rule_action import StorageBucketLifecycleRuleAction
from .storage_bucket_lifecycle_rule_condition import StorageBucketLifecycleRuleCondition


class StorageBucketLifecycleRule(UniversalBaseModel):
    """
    A lifecycle rule for a bucket
    """

    action: StorageBucketLifecycleRuleAction = pydantic.Field()
    """
    Rule action
    """

    condition: StorageBucketLifecycleRuleCondition = pydantic.Field()
    """
    Rule condition
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .resend_broadcast import ResendBroadcast


class ResendSegment(UniversalBaseModel):
    """
    Resend Segment object - parent containing broadcasts that target this segment
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Segment ID (read-only, set by Resend)
    """

    name: str = pydantic.Field()
    """
    Segment name
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    Creation timestamp
    """

    broadcasts: typing.Optional[typing.List[ResendBroadcast]] = pydantic.Field(default=None)
    """
    Broadcasts sent to this segment
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GmailDraft(UniversalBaseModel):
    """
    Gmail Draft object with essential fields
    """

    subject: str = pydantic.Field()
    """
    Draft subject (required)
    """

    to: str = pydantic.Field()
    """
    Recipient email address (required)
    """

    cc: typing.Optional[str] = pydantic.Field(default=None)
    """
    CC email addresses (comma-separated)
    """

    bcc: typing.Optional[str] = pydantic.Field(default=None)
    """
    BCC email addresses (comma-separated)
    """

    body: str = pydantic.Field()
    """
    Draft body content (required)
    """

    from_: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="from")] = pydantic.Field(default=None)
    """
    Sender email address (optional, defaults to authenticated user)
    """

    reply_to: typing.Optional[str] = pydantic.Field(default=None)
    """
    Reply-to email address
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .click_up_task import ClickUpTask


class ClickUpList(UniversalBaseModel):
    """
    ClickUp List object
    """

    name: str = pydantic.Field()
    """
    List name
    """

    content: typing.Optional[str] = pydantic.Field(default=None)
    """
    List description/content
    """

    tasks: typing.Optional[typing.List[ClickUpTask]] = pydantic.Field(default=None)
    """
    Tasks in this list
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .confluence_comment import ConfluenceComment


class ConfluencePage(UniversalBaseModel):
    """
    Confluence Page object
    """

    title: str = pydantic.Field()
    """
    Page title
    """

    body: str = pydantic.Field()
    """
    Page content (storage format)
    """

    children: typing.Optional[typing.List["ConfluencePage"]] = pydantic.Field(default=None)
    """
    Child pages
    """

    comments: typing.Optional[typing.List[ConfluenceComment]] = pydantic.Field(default=None)
    """
    Comments on this page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ConfluencePage)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SandboxMcpServer(str, enum.Enum):
    """
    Supported MCP servers for sandboxing
    """

    JIRA = "jira"
    GITHUB = "github"
    SALESFORCE = "salesforce"
    HUBSPOT = "hubspot"
    NOTION = "notion"
    AIRTABLE = "airtable"
    LINEAR = "linear"
    ASANA = "asana"
    GOOGLE_SHEETS = "google_sheets"
    GOOGLE_DRIVE = "google_drive"
    GOOGLE_DOCS = "google_docs"
    GMAIL = "gmail"
    GOOGLE_CALENDAR = "google_calendar"
    GOOGLE_FORMS = "google_forms"
    CLICKUP = "clickup"
    CLOSE = "close"
    MONDAY = "monday"
    ONEDRIVE = "onedrive"
    MICROSOFT_TEAMS = "microsoft_teams"
    OUTLOOK_MAIL = "outlook_mail"
    CAL_COM = "Cal.com"
    QUICKBOOKS = "quickbooks"
    MONEYBIRD = "moneybird"
    DROPBOX = "dropbox"
    SHOPIFY = "shopify"
    OUTLOOK_CALENDAR = "outlook_calendar"
    RESEND = "resend"
    WORDPRESS = "wordpress"
    MEM0 = "mem0"
    SUPABASE = "supabase"
    SLACK = "slack"
    CONFLUENCE = "confluence"
    DISCORD = "discord"
    SNOWFLAKE = "snowflake"
    GOOGLE_CLOUD = "google_cloud"

    def visit(
        self,
        jira: typing.Callable[[], T_Result],
        github: typing.Callable[[], T_Result],
        salesforce: typing.Callable[[], T_Result],
        hubspot: typing.Callable[[], T_Result],
        notion: typing.Callable[[], T_Result],
        airtable: typing.Callable[[], T_Result],
        linear: typing.Callable[[], T_Result],
        asana: typing.Callable[[], T_Result],
        google_sheets: typing.Callable[[], T_Result],
        google_drive: typing.Callable[[], T_Result],
        google_docs: typing.Callable[[], T_Result],
        gmail: typing.Callable[[], T_Result],
        google_calendar: typing.Callable[[], T_Result],
        google_forms: typing.Callable[[], T_Result],
        clickup: typing.Callable[[], T_Result],
        close: typing.Callable[[], T_Result],
        monday: typing.Callable[[], T_Result],
        onedrive: typing.Callable[[], T_Result],
        microsoft_teams: typing.Callable[[], T_Result],
        outlook_mail: typing.Callable[[], T_Result],
        cal_com: typing.Callable[[], T_Result],
        quickbooks: typing.Callable[[], T_Result],
        moneybird: typing.Callable[[], T_Result],
        dropbox: typing.Callable[[], T_Result],
        shopify: typing.Callable[[], T_Result],
        outlook_calendar: typing.Callable[[], T_Result],
        resend: typing.Callable[[], T_Result],
        wordpress: typing.Callable[[], T_Result],
        mem0: typing.Callable[[], T_Result],
        supabase: typing.Callable[[], T_Result],
        slack: typing.Callable[[], T_Result],
        confluence: typing.Callable[[], T_Result],
        discord: typing.Callable[[], T_Result],
        snowflake: typing.Callable[[], T_Result],
        google_cloud: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SandboxMcpServer.JIRA:
            return jira()
        if self is SandboxMcpServer.GITHUB:
            return github()
        if self is SandboxMcpServer.SALESFORCE:
            return salesforce()
        if self is SandboxMcpServer.HUBSPOT:
            return hubspot()
        if self is SandboxMcpServer.NOTION:
            return notion()
        if self is SandboxMcpServer.AIRTABLE:
            return airtable()
        if self is SandboxMcpServer.LINEAR:
            return linear()
        if self is SandboxMcpServer.ASANA:
            return asana()
        if self is SandboxMcpServer.GOOGLE_SHEETS:
            return google_sheets()
        if self is SandboxMcpServer.GOOGLE_DRIVE:
            return google_drive()
        if self is SandboxMcpServer.GOOGLE_DOCS:
            return google_docs()
        if self is SandboxMcpServer.GMAIL:
            return gmail()
        if self is SandboxMcpServer.GOOGLE_CALENDAR:
            return google_calendar()
        if self is SandboxMcpServer.GOOGLE_FORMS:
            return google_forms()
        if self is SandboxMcpServer.CLICKUP:
            return clickup()
        if self is SandboxMcpServer.CLOSE:
            return close()
        if self is SandboxMcpServer.MONDAY:
            return monday()
        if self is SandboxMcpServer.ONEDRIVE:
            return onedrive()
        if self is SandboxMcpServer.MICROSOFT_TEAMS:
            return microsoft_teams()
        if self is SandboxMcpServer.OUTLOOK_MAIL:
            return outlook_mail()
        if self is SandboxMcpServer.CAL_COM:
            return cal_com()
        if self is SandboxMcpServer.QUICKBOOKS:
            return quickbooks()
        if self is SandboxMcpServer.MONEYBIRD:
            return moneybird()
        if self is SandboxMcpServer.DROPBOX:
            return dropbox()
        if self is SandboxMcpServer.SHOPIFY:
            return shopify()
        if self is SandboxMcpServer.OUTLOOK_CALENDAR:
            return outlook_calendar()
        if self is SandboxMcpServer.RESEND:
            return resend()
        if self is SandboxMcpServer.WORDPRESS:
            return wordpress()
        if self is SandboxMcpServer.MEM0:
            return mem0()
        if self is SandboxMcpServer.SUPABASE:
            return supabase()
        if self is SandboxMcpServer.SLACK:
            return slack()
        if self is SandboxMcpServer.CONFLUENCE:
            return confluence()
        if self is SandboxMcpServer.DISCORD:
            return discord()
        if self is SandboxMcpServer.SNOWFLAKE:
            return snowflake()
        if self is SandboxMcpServer.GOOGLE_CLOUD:
            return google_cloud()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NotionBlock(UniversalBaseModel):
    """
    Notion Block object - fundamental content unit.

    Blocks can be: paragraph, heading_1, heading_2, heading_3, bulleted_list_item,
    numbered_list_item, to_do, toggle, code, quote, callout, etc.
    """

    type: str = pydantic.Field()
    """
    Block type (paragraph, heading_1, heading_2, etc.)
    """

    content: str = pydantic.Field()
    """
    Block text content
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .linear_issue import LinearIssue


class LinearProject(UniversalBaseModel):
    """
    Linear Project object
    """

    name: str = pydantic.Field()
    """
    Project name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project description
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project state (planned, started, paused, completed, canceled)
    """

    issues: typing.Optional[typing.List[LinearIssue]] = pydantic.Field(default=None)
    """
    Issues in this project
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.big_query_dataset import BigQueryDataset
from ..types.big_query_table import BigQueryTable
from ..types.compute_instance import ComputeInstance
from ..types.create_sandbox_response import CreateSandboxResponse
from ..types.dump_sandbox_response_google_cloud_data import DumpSandboxResponseGoogleCloudData
from ..types.initialize_sandbox_response import InitializeSandboxResponse
from ..types.log_bucket import LogBucket
from ..types.log_entry import LogEntry
from ..types.log_sink import LogSink
from ..types.release_sandbox_response import ReleaseSandboxResponse
from ..types.reset_sandbox_response import ResetSandboxResponse
from ..types.sandbox_info import SandboxInfo
from ..types.sandbox_mcp_server import SandboxMcpServer
from ..types.storage_bucket import StorageBucket
from ..types.storage_object import StorageObject
from .raw_client import AsyncRawSandboxClient, RawSandboxClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SandboxClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSandboxClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSandboxClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSandboxClient
        """
        return self._raw_client

    def create_sandbox(
        self, server_name: SandboxMcpServer, *, request_options: typing.Optional[RequestOptions] = None
    ) -> CreateSandboxResponse:
        """
        Acquire an idle sandbox instance for a specific MCP server. The sandbox will be marked as 'occupied'.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateSandboxResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, SandboxMcpServer

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.create_sandbox(
            server_name=SandboxMcpServer.JIRA,
        )
        """
        _response = self._raw_client.create_sandbox(server_name, request_options=request_options)
        return _response.data

    def get_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SandboxInfo:
        """
        Retrieve detailed information about a specific sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SandboxInfo
            Successful Response

        Examples
        --------
        from klavis import Klavis, SandboxMcpServer

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.get_sandbox(
            server_name=SandboxMcpServer.JIRA,
            sandbox_id="sandbox_id",
        )
        """
        _response = self._raw_client.get_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    def delete_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ReleaseSandboxResponse:
        """
        Release an occupied sandbox back to idle state and marks the sandbox as available for reuse.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ReleaseSandboxResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, SandboxMcpServer

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.delete_sandbox(
            server_name=SandboxMcpServer.JIRA,
            sandbox_id="sandbox_id",
        )
        """
        _response = self._raw_client.delete_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    def reset_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ResetSandboxResponse:
        """
        Reset the sandbox to its initial empty state, clearing all data while maintaining the sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResetSandboxResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, SandboxMcpServer

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.reset_sandbox(
            server_name=SandboxMcpServer.JIRA,
            sandbox_id="sandbox_id",
        )
        """
        _response = self._raw_client.reset_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    def initialize_sandbox(
        self,
        sandbox_id: str,
        *,
        datasets: typing.Optional[typing.Sequence[BigQueryDataset]] = OMIT,
        tables: typing.Optional[typing.Sequence[BigQueryTable]] = OMIT,
        buckets: typing.Optional[typing.Sequence[StorageBucket]] = OMIT,
        objects: typing.Optional[typing.Sequence[StorageObject]] = OMIT,
        log_entries: typing.Optional[typing.Sequence[LogEntry]] = OMIT,
        log_sinks: typing.Optional[typing.Sequence[LogSink]] = OMIT,
        log_buckets: typing.Optional[typing.Sequence[LogBucket]] = OMIT,
        instances: typing.Optional[typing.Sequence[ComputeInstance]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> InitializeSandboxResponse:
        """
        Initialize the sandbox with google_cloud-specific data following the defined schema.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        datasets : typing.Optional[typing.Sequence[BigQueryDataset]]
            BigQuery datasets

        tables : typing.Optional[typing.Sequence[BigQueryTable]]
            BigQuery tables

        buckets : typing.Optional[typing.Sequence[StorageBucket]]
            Cloud Storage buckets

        objects : typing.Optional[typing.Sequence[StorageObject]]
            Cloud Storage objects

        log_entries : typing.Optional[typing.Sequence[LogEntry]]
            Log entries

        log_sinks : typing.Optional[typing.Sequence[LogSink]]
            Log sinks

        log_buckets : typing.Optional[typing.Sequence[LogBucket]]
            Log buckets

        instances : typing.Optional[typing.Sequence[ComputeInstance]]
            Compute Engine instances

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        InitializeSandboxResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.initialize_sandbox(
            sandbox_id="sandbox_id",
        )
        """
        _response = self._raw_client.initialize_sandbox(
            sandbox_id,
            datasets=datasets,
            tables=tables,
            buckets=buckets,
            objects=objects,
            log_entries=log_entries,
            log_sinks=log_sinks,
            log_buckets=log_buckets,
            instances=instances,
            request_options=request_options,
        )
        return _response.data

    def dump_sandbox(
        self, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DumpSandboxResponseGoogleCloudData:
        """
        Export all data from the sandbox in the same format used for initialization.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DumpSandboxResponseGoogleCloudData
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.sandbox.dump_sandbox(
            sandbox_id="sandbox_id",
        )
        """
        _response = self._raw_client.dump_sandbox(sandbox_id, request_options=request_options)
        return _response.data


class AsyncSandboxClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSandboxClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSandboxClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSandboxClient
        """
        return self._raw_client

    async def create_sandbox(
        self, server_name: SandboxMcpServer, *, request_options: typing.Optional[RequestOptions] = None
    ) -> CreateSandboxResponse:
        """
        Acquire an idle sandbox instance for a specific MCP server. The sandbox will be marked as 'occupied'.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateSandboxResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, SandboxMcpServer

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.create_sandbox(
                server_name=SandboxMcpServer.JIRA,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_sandbox(server_name, request_options=request_options)
        return _response.data

    async def get_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SandboxInfo:
        """
        Retrieve detailed information about a specific sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SandboxInfo
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, SandboxMcpServer

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.get_sandbox(
                server_name=SandboxMcpServer.JIRA,
                sandbox_id="sandbox_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    async def delete_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ReleaseSandboxResponse:
        """
        Release an occupied sandbox back to idle state and marks the sandbox as available for reuse.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ReleaseSandboxResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, SandboxMcpServer

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.delete_sandbox(
                server_name=SandboxMcpServer.JIRA,
                sandbox_id="sandbox_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    async def reset_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ResetSandboxResponse:
        """
        Reset the sandbox to its initial empty state, clearing all data while maintaining the sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResetSandboxResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, SandboxMcpServer

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.reset_sandbox(
                server_name=SandboxMcpServer.JIRA,
                sandbox_id="sandbox_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.reset_sandbox(server_name, sandbox_id, request_options=request_options)
        return _response.data

    async def initialize_sandbox(
        self,
        sandbox_id: str,
        *,
        datasets: typing.Optional[typing.Sequence[BigQueryDataset]] = OMIT,
        tables: typing.Optional[typing.Sequence[BigQueryTable]] = OMIT,
        buckets: typing.Optional[typing.Sequence[StorageBucket]] = OMIT,
        objects: typing.Optional[typing.Sequence[StorageObject]] = OMIT,
        log_entries: typing.Optional[typing.Sequence[LogEntry]] = OMIT,
        log_sinks: typing.Optional[typing.Sequence[LogSink]] = OMIT,
        log_buckets: typing.Optional[typing.Sequence[LogBucket]] = OMIT,
        instances: typing.Optional[typing.Sequence[ComputeInstance]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> InitializeSandboxResponse:
        """
        Initialize the sandbox with google_cloud-specific data following the defined schema.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        datasets : typing.Optional[typing.Sequence[BigQueryDataset]]
            BigQuery datasets

        tables : typing.Optional[typing.Sequence[BigQueryTable]]
            BigQuery tables

        buckets : typing.Optional[typing.Sequence[StorageBucket]]
            Cloud Storage buckets

        objects : typing.Optional[typing.Sequence[StorageObject]]
            Cloud Storage objects

        log_entries : typing.Optional[typing.Sequence[LogEntry]]
            Log entries

        log_sinks : typing.Optional[typing.Sequence[LogSink]]
            Log sinks

        log_buckets : typing.Optional[typing.Sequence[LogBucket]]
            Log buckets

        instances : typing.Optional[typing.Sequence[ComputeInstance]]
            Compute Engine instances

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        InitializeSandboxResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.initialize_sandbox(
                sandbox_id="sandbox_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.initialize_sandbox(
            sandbox_id,
            datasets=datasets,
            tables=tables,
            buckets=buckets,
            objects=objects,
            log_entries=log_entries,
            log_sinks=log_sinks,
            log_buckets=log_buckets,
            instances=instances,
            request_options=request_options,
        )
        return _response.data

    async def dump_sandbox(
        self, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DumpSandboxResponseGoogleCloudData:
        """
        Export all data from the sandbox in the same format used for initialization.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DumpSandboxResponseGoogleCloudData
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sandbox.dump_sandbox(
                sandbox_id="sandbox_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.dump_sandbox(sandbox_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class HubSpotTask(UniversalBaseModel):
    """
    HubSpot Task object.
    Can be associated with: Contacts, Companies, Deals, Tickets.
    """

    subject: str = pydantic.Field()
    """
    Task subject/title
    """

    body: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task body/description
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task status (NOT_STARTED, IN_PROGRESS, COMPLETED, WAITING, DEFERRED)
    """

    priority: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task priority (HIGH, MEDIUM, LOW)
    """

    due_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task due date (ISO 8601 format)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class TimeSlot(UniversalBaseModel):
    """
    Represents a recurring time slot in a schedule.

    Attributes:
        days: List of weekday names (Monday, Tuesday, etc.)
        startTime: Start time in HH:MM format (24-hour)
        endTime: End time in HH:MM format (24-hour)
    """

    days: typing.List[str]
    start_time: typing_extensions.Annotated[str, FieldMetadata(alias="startTime")]
    end_time: typing_extensions.Annotated[str, FieldMetadata(alias="endTime")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .airtable_field import AirtableField
from .airtable_record import AirtableRecord


class AirtableTable(UniversalBaseModel):
    """
    Airtable Table object
    """

    name: str = pydantic.Field()
    """
    Table name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Table description
    """

    fields: typing.Optional[typing.List[AirtableField]] = pydantic.Field(default=None)
    """
    Field definitions for this table
    """

    records: typing.Optional[typing.List[AirtableRecord]] = pydantic.Field(default=None)
    """
    Records in this table
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from ..core.serialization import FieldMetadata
from .big_query_dataset import BigQueryDataset
from .big_query_table import BigQueryTable
from .compute_instance import ComputeInstance
from .log_bucket import LogBucket
from .log_entry import LogEntry
from .log_sink import LogSink
from .storage_bucket import StorageBucket
from .storage_object import StorageObject


class GoogleCloudDataOutput(UniversalBaseModel):
    """
    Complete Google Cloud sandbox data structure
    """

    datasets: typing.Optional[typing.List[BigQueryDataset]] = pydantic.Field(default=None)
    """
    BigQuery datasets
    """

    tables: typing.Optional[typing.List[BigQueryTable]] = pydantic.Field(default=None)
    """
    BigQuery tables
    """

    buckets: typing.Optional[typing.List[StorageBucket]] = pydantic.Field(default=None)
    """
    Cloud Storage buckets
    """

    objects: typing.Optional[typing.List[StorageObject]] = pydantic.Field(default=None)
    """
    Cloud Storage objects
    """

    log_entries: typing_extensions.Annotated[
        typing.Optional[typing.List[LogEntry]], FieldMetadata(alias="logEntries")
    ] = pydantic.Field(default=None)
    """
    Log entries
    """

    log_sinks: typing_extensions.Annotated[typing.Optional[typing.List[LogSink]], FieldMetadata(alias="logSinks")] = (
        pydantic.Field(default=None)
    )
    """
    Log sinks
    """

    log_buckets: typing_extensions.Annotated[
        typing.Optional[typing.List[LogBucket]], FieldMetadata(alias="logBuckets")
    ] = pydantic.Field(default=None)
    """
    Log buckets
    """

    instances: typing.Optional[typing.List[ComputeInstance]] = pydantic.Field(default=None)
    """
    Compute Engine instances
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(GoogleCloudDataOutput)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class MoneybirdProduct(UniversalBaseModel):
    """
    Moneybird product/service - API format

    Attributes:
        description: Product description
        title: Product title/name
        price: Product price
        currency: Currency code (e.g., 'EUR')
        identifier: Product SKU/identifier
        frequency: Billing frequency (optional, for recurring products)
        frequency_type: Frequency type (e.g., 'month', 'year')
    """

    description: str = pydantic.Field()
    """
    Product description
    """

    title: str = pydantic.Field()
    """
    Product title/name
    """

    price: str = pydantic.Field()
    """
    Product price as string
    """

    currency: str = pydantic.Field()
    """
    Currency code (e.g., 'EUR')
    """

    identifier: str = pydantic.Field()
    """
    Product SKU/identifier
    """

    frequency: typing.Optional[int] = pydantic.Field(default=None)
    """
    Billing frequency
    """

    frequency_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Frequency type (month, year)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class QuickBooksData(UniversalBaseModel):
    """
    Complete QuickBooks sandbox data structure

    Note: For dump operations, accounts/customers/etc. will contain full API response objects
    with additional fields beyond the minimal input schema. This is expected behavior.
    """

    accounts: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    List of accounts (input: minimal, output: full API objects)
    """

    customers: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(
        default=None
    )
    """
    List of customers (input: minimal, output: full API objects)
    """

    vendors: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    List of vendors (input: minimal, output: full API objects)
    """

    invoices: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    List of invoices (input: minimal, output: full API objects)
    """

    payments: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    List of payments (input: minimal, output: full API objects)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class StorageBucketLifecycleRuleAction(UniversalBaseModel):
    """
    Action for a lifecycle rule
    """

    type: str = pydantic.Field()
    """
    Action type (Delete, SetStorageClass)
    """

    storage_class: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="storageClass")] = (
        pydantic.Field(default=None)
    )
    """
    Storage class for SetStorageClass action
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class BigQueryTableFieldSchema(UniversalBaseModel):
    """
    Schema for a BigQuery table field
    """

    name: str = pydantic.Field()
    """
    Field name
    """

    type: str = pydantic.Field()
    """
    Field type (STRING, INTEGER, FLOAT, BOOLEAN, TIMESTAMP, RECORD, etc.)
    """

    mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field mode (NULLABLE, REQUIRED, REPEATED)
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Field description
    """

    fields: typing.Optional[typing.List["BigQueryTableFieldSchema"]] = pydantic.Field(default=None)
    """
    Nested fields for RECORD type
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(BigQueryTableFieldSchema)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NotionComment(UniversalBaseModel):
    """
    Notion Comment object - can be attached to pages or blocks
    """

    text: str = pydantic.Field()
    """
    Comment text content (rich text)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoogleFormsItem(UniversalBaseModel):
    """
    Form item - matches API Item object. Uses Dict for flexibility to match API structure.
    """

    item_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="itemId")] = pydantic.Field(
        default=None
    )
    """
    The item ID
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    The title of the item
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the item
    """

    question_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="questionItem")
    ] = pydantic.Field(default=None)
    """
    Poses a question to the user
    """

    question_group_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="questionGroupItem")
    ] = pydantic.Field(default=None)
    """
    Poses one or more questions with a single major prompt
    """

    page_break_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="pageBreakItem")
    ] = pydantic.Field(default=None)
    """
    Starts a new page with a title
    """

    text_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="textItem")
    ] = pydantic.Field(default=None)
    """
    Displays a title and description on the page
    """

    image_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="imageItem")
    ] = pydantic.Field(default=None)
    """
    Displays an image on the page
    """

    video_item: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="videoItem")
    ] = pydantic.Field(default=None)
    """
    Displays a video on the page
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SalesforceCase(UniversalBaseModel):
    """
    Salesforce Case object with comprehensive field support
    """

    subject: typing_extensions.Annotated[str, FieldMetadata(alias="Subject")] = pydantic.Field()
    """
    Case subject (required)
    """

    status: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Status")] = pydantic.Field(
        default=None
    )
    """
    Case status (e.g., New, Working, Closed)
    """

    priority: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Priority")] = pydantic.Field(
        default=None
    )
    """
    Priority (e.g., High, Medium, Low)
    """

    origin: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Origin")] = pydantic.Field(
        default=None
    )
    """
    Case origin (e.g., Phone, Email, Web)
    """

    type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Type")] = pydantic.Field(default=None)
    """
    Case type (e.g., Problem, Question, Feature Request)
    """

    reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Reason")] = pydantic.Field(
        default=None
    )
    """
    Case reason
    """

    account_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="AccountId")] = pydantic.Field(
        default=None
    )
    """
    Related account ID (18-char Salesforce ID)
    """

    contact_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactId")] = pydantic.Field(
        default=None
    )
    """
    Related contact ID (18-char Salesforce ID)
    """

    description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Description")] = pydantic.Field(
        default=None
    )
    """
    Case description
    """

    supplied_email: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="SuppliedEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Supplied email address
    """

    supplied_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="SuppliedName")] = (
        pydantic.Field(default=None)
    )
    """
    Supplied name
    """

    supplied_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="SuppliedPhone")] = (
        pydantic.Field(default=None)
    )
    """
    Supplied phone number
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sandbox_mcp_server import SandboxMcpServer
from .sandbox_status import SandboxStatus


class CreateSandboxResponse(UniversalBaseModel):
    """
    Response model for sandbox acquisition
    """

    sandbox_id: str = pydantic.Field()
    """
    Unique identifier for the acquired sandbox
    """

    server_url: str = pydantic.Field()
    """
    URL to connect to the MCP server
    """

    server_name: SandboxMcpServer = pydantic.Field()
    """
    The MCP server name
    """

    status: SandboxStatus = pydantic.Field()
    """
    Current status of the sandbox
    """

    message: str = pydantic.Field()
    """
    Status message
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .notion_page import NotionPage


class NotionDataSource(UniversalBaseModel):
    """
    Notion Data Source object - represents a table within a database.

    New in API version 2025-09-03:
    - A database can contain multiple data sources
    - Each data source has its own schema (properties)
    - Pages within a data source follow that schema
    """

    name: str = pydantic.Field()
    """
    Data source name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Data source description
    """

    schema_: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="schema")
    ] = pydantic.Field(default=None)
    """
    Schema definition (property types and configurations)
    """

    pages: typing.Optional[typing.List[NotionPage]] = pydantic.Field(default=None)
    """
    Pages (items/rows) in this data source
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .shopify_address import ShopifyAddress


class ShopifyCustomer(UniversalBaseModel):
    """
    Shopify customer data

    Attributes:
        email: Customer email address (optional - may not be present in API response)
        first_name: Customer first name (optional - may not be present in API response)
        last_name: Customer last name (optional - may not be present in API response)
        addresses: List of customer addresses
    """

    email: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer email address
    """

    first_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer first name
    """

    last_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer last name
    """

    addresses: typing.Optional[typing.List[ShopifyAddress]] = pydantic.Field(default=None)
    """
    List of customer addresses
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .override import Override
from .time_slot import TimeSlot


class CalcomSchedule(UniversalBaseModel):
    """
    Schedule data for creating a new schedule via Cal.com API.

    Attributes:
        name: Human-readable schedule name
        timeZone: IANA timezone (e.g., "America/New_York")
        isDefault: Whether this is the default schedule for the user
        availability: List of recurring time slots (optional, defaults to Mon-Fri 9-17)
        overrides: List of date-specific availability overrides (optional)
    """

    name: str = pydantic.Field()
    """
    Human-readable schedule name
    """

    time_zone: typing_extensions.Annotated[str, FieldMetadata(alias="timeZone")] = pydantic.Field()
    """
    IANA timezone (e.g., 'America/New_York')
    """

    is_default: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="isDefault")] = pydantic.Field(
        default=None
    )
    """
    Whether this is the default schedule
    """

    availability: typing.Optional[typing.List[TimeSlot]] = pydantic.Field(default=None)
    """
    List of recurring time slots
    """

    overrides: typing.Optional[typing.List[Override]] = pydantic.Field(default=None)
    """
    List of date-specific availability overrides
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SnowflakeColumn(UniversalBaseModel):
    """
    Snowflake Table Column definition
    """

    name: str = pydantic.Field()
    """
    Column name
    """

    data_type: str = pydantic.Field()
    """
    Column data type (e.g., VARCHAR, NUMBER, TIMESTAMP)
    """

    nullable: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the column can be NULL
    """

    default: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default value for the column
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.zoom_o_auth_success_response import ZoomOAuthSuccessResponse
from .raw_client import AsyncRawZoomOauthClient, RawZoomOauthClient


class ZoomOauthClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawZoomOauthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawZoomOauthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawZoomOauthClient
        """
        return self._raw_client

    def refresh_token(
        self, *, instance_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ZoomOAuthSuccessResponse:
        """
        Parameters
        ----------
        instance_id : str
            Instance ID for which to refresh the token

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ZoomOAuthSuccessResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.zoom_oauth.refresh_token(
            instance_id="instance_id",
        )
        """
        _response = self._raw_client.refresh_token(instance_id=instance_id, request_options=request_options)
        return _response.data


class AsyncZoomOauthClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawZoomOauthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawZoomOauthClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawZoomOauthClient
        """
        return self._raw_client

    async def refresh_token(
        self, *, instance_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ZoomOAuthSuccessResponse:
        """
        Parameters
        ----------
        instance_id : str
            Instance ID for which to refresh the token

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ZoomOAuthSuccessResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.zoom_oauth.refresh_token(
                instance_id="instance_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.refresh_token(instance_id=instance_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class JiraBoard(UniversalBaseModel):
    """
    Jira Board object
    """

    name: str = pydantic.Field()
    """
    Board name
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Board type (scrum or kanban)
    """

    project_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    Key of the project this board belongs to (for initialization)
    """

    filter_jql: typing.Optional[str] = pydantic.Field(default=None)
    """
    JQL for the board filter
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GetUserAuthResponse(UniversalBaseModel):
    success: bool
    user_id: typing_extensions.Annotated[str, FieldMetadata(alias="userId")] = pydantic.Field()
    """
    The user identifier
    """

    server_name: typing_extensions.Annotated[str, FieldMetadata(alias="serverName")] = pydantic.Field()
    """
    The name of the server
    """

    auth_data: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="authData")
    ] = pydantic.Field(default=None)
    """
    The authentication data if available
    """

    is_authenticated: typing_extensions.Annotated[bool, FieldMetadata(alias="isAuthenticated")] = pydantic.Field()
    """
    Whether the server has authentication data configured
    """

    message: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class McpServerName(str, enum.Enum):
    AFFINITY = "Affinity"
    AIRTABLE = "Airtable"
    ASANA = "Asana"
    ATTIO = "Attio"
    BOX = "Box"
    BRAVE_SEARCH = "Brave Search"
    CAL_COM = "Cal.com"
    CANVA = "Canva"
    CLICKUP = "ClickUp"
    CLOSE = "Close"
    CLOUDFLARE = "Cloudflare"
    COINBASE = "Coinbase"
    CONFLUENCE = "Confluence"
    DIALPAD = "Dialpad"
    DISCORD = "Discord"
    DOC2MARKDOWN = "Doc2markdown"
    DOCUSIGN = "DocuSign"
    DROPBOX = "Dropbox"
    ELEVEN_LABS = "ElevenLabs"
    EXA = "Exa"
    FATHOM = "Fathom"
    FIGMA = "Figma"
    FIREFLIES = "Fireflies"
    FIRECRAWL_DEEP_RESEARCH = "Firecrawl Deep Research"
    FIRECRAWL_WEB_SEARCH = "Firecrawl Web Search"
    FRESHDESK = "Freshdesk"
    GITHUB = "GitHub"
    GITLAB = "GitLab"
    GMAIL = "Gmail"
    GONG = "Gong"
    GOOGLE_CALENDAR = "Google Calendar"
    GOOGLE_DOCS = "Google Docs"
    GOOGLE_DRIVE = "Google Drive"
    GOOGLE_JOBS = "Google Jobs"
    GOOGLE_SHEETS = "Google Sheets"
    GOOGLE_FORMS = "Google Forms"
    GOOGLE_CLOUD = "Google Cloud"
    HACKER_NEWS = "Hacker News"
    HEYGEN = "Heygen"
    HUBSPOT = "HubSpot"
    JIRA = "Jira"
    KLAVIYO = "Klaviyo"
    KLAVIS_REPORT_GEN = "Klavis ReportGen"
    LINEAR = "Linear"
    LINKEDIN = "LinkedIn"
    MARKDOWN2DOC = "Markdown2doc"
    MEM0 = "Mem0"
    MICROSOFT_TEAMS = "Microsoft Teams"
    MIXPANEL = "Mixpanel"
    MONDAY = "Monday"
    MONEYBIRD = "Moneybird"
    MOTION = "Motion"
    NOTION = "Notion"
    ONEDRIVE = "OneDrive"
    OPENROUTER = "Openrouter"
    OUTLOOK_MAIL = "Outlook Mail"
    OUTLOOK_CALENDAR = "Outlook Calendar"
    PAGERDUTY = "PagerDuty"
    PIPEDRIVE = "Pipedrive"
    PLAI = "Plai"
    POSTGRES = "Postgres"
    POSTHOG = "PostHog"
    POSTMAN = "Postman"
    QUICKBOOKS = "QuickBooks"
    RESEND = "Resend"
    SALESFORCE = "Salesforce"
    SENDGRID = "SendGrid"
    SHOPIFY = "Shopify"
    SLACK = "Slack"
    SNOWFLAKE = "Snowflake"
    STRIPE = "Stripe"
    SUPABASE = "Supabase"
    TAVILY = "Tavily"
    VERCEL = "Vercel"
    WHATSAPP = "WhatsApp"
    WORDPRESS = "WordPress"
    YOUTUBE = "YouTube"
    ZENDESK = "Zendesk"
    SERVICE_NOW = "ServiceNow"

    def visit(
        self,
        affinity: typing.Callable[[], T_Result],
        airtable: typing.Callable[[], T_Result],
        asana: typing.Callable[[], T_Result],
        attio: typing.Callable[[], T_Result],
        box: typing.Callable[[], T_Result],
        brave_search: typing.Callable[[], T_Result],
        cal_com: typing.Callable[[], T_Result],
        canva: typing.Callable[[], T_Result],
        clickup: typing.Callable[[], T_Result],
        close: typing.Callable[[], T_Result],
        cloudflare: typing.Callable[[], T_Result],
        coinbase: typing.Callable[[], T_Result],
        confluence: typing.Callable[[], T_Result],
        dialpad: typing.Callable[[], T_Result],
        discord: typing.Callable[[], T_Result],
        doc2markdown: typing.Callable[[], T_Result],
        docusign: typing.Callable[[], T_Result],
        dropbox: typing.Callable[[], T_Result],
        eleven_labs: typing.Callable[[], T_Result],
        exa: typing.Callable[[], T_Result],
        fathom: typing.Callable[[], T_Result],
        figma: typing.Callable[[], T_Result],
        fireflies: typing.Callable[[], T_Result],
        firecrawl_deep_research: typing.Callable[[], T_Result],
        firecrawl_web_search: typing.Callable[[], T_Result],
        freshdesk: typing.Callable[[], T_Result],
        github: typing.Callable[[], T_Result],
        gitlab: typing.Callable[[], T_Result],
        gmail: typing.Callable[[], T_Result],
        gong: typing.Callable[[], T_Result],
        google_calendar: typing.Callable[[], T_Result],
        google_docs: typing.Callable[[], T_Result],
        google_drive: typing.Callable[[], T_Result],
        google_jobs: typing.Callable[[], T_Result],
        google_sheets: typing.Callable[[], T_Result],
        google_forms: typing.Callable[[], T_Result],
        google_cloud: typing.Callable[[], T_Result],
        hacker_news: typing.Callable[[], T_Result],
        heygen: typing.Callable[[], T_Result],
        hubspot: typing.Callable[[], T_Result],
        jira: typing.Callable[[], T_Result],
        klaviyo: typing.Callable[[], T_Result],
        klavis_report_gen: typing.Callable[[], T_Result],
        linear: typing.Callable[[], T_Result],
        linkedin: typing.Callable[[], T_Result],
        markdown2doc: typing.Callable[[], T_Result],
        mem0: typing.Callable[[], T_Result],
        microsoft_teams: typing.Callable[[], T_Result],
        mixpanel: typing.Callable[[], T_Result],
        monday: typing.Callable[[], T_Result],
        moneybird: typing.Callable[[], T_Result],
        motion: typing.Callable[[], T_Result],
        notion: typing.Callable[[], T_Result],
        onedrive: typing.Callable[[], T_Result],
        openrouter: typing.Callable[[], T_Result],
        outlook_mail: typing.Callable[[], T_Result],
        outlook_calendar: typing.Callable[[], T_Result],
        pagerduty: typing.Callable[[], T_Result],
        pipedrive: typing.Callable[[], T_Result],
        plai: typing.Callable[[], T_Result],
        postgres: typing.Callable[[], T_Result],
        posthog: typing.Callable[[], T_Result],
        postman: typing.Callable[[], T_Result],
        quickbooks: typing.Callable[[], T_Result],
        resend: typing.Callable[[], T_Result],
        salesforce: typing.Callable[[], T_Result],
        sendgrid: typing.Callable[[], T_Result],
        shopify: typing.Callable[[], T_Result],
        slack: typing.Callable[[], T_Result],
        snowflake: typing.Callable[[], T_Result],
        stripe: typing.Callable[[], T_Result],
        supabase: typing.Callable[[], T_Result],
        tavily: typing.Callable[[], T_Result],
        vercel: typing.Callable[[], T_Result],
        whatsapp: typing.Callable[[], T_Result],
        wordpress: typing.Callable[[], T_Result],
        youtube: typing.Callable[[], T_Result],
        zendesk: typing.Callable[[], T_Result],
        service_now: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is McpServerName.AFFINITY:
            return affinity()
        if self is McpServerName.AIRTABLE:
            return airtable()
        if self is McpServerName.ASANA:
            return asana()
        if self is McpServerName.ATTIO:
            return attio()
        if self is McpServerName.BOX:
            return box()
        if self is McpServerName.BRAVE_SEARCH:
            return brave_search()
        if self is McpServerName.CAL_COM:
            return cal_com()
        if self is McpServerName.CANVA:
            return canva()
        if self is McpServerName.CLICKUP:
            return clickup()
        if self is McpServerName.CLOSE:
            return close()
        if self is McpServerName.CLOUDFLARE:
            return cloudflare()
        if self is McpServerName.COINBASE:
            return coinbase()
        if self is McpServerName.CONFLUENCE:
            return confluence()
        if self is McpServerName.DIALPAD:
            return dialpad()
        if self is McpServerName.DISCORD:
            return discord()
        if self is McpServerName.DOC2MARKDOWN:
            return doc2markdown()
        if self is McpServerName.DOCUSIGN:
            return docusign()
        if self is McpServerName.DROPBOX:
            return dropbox()
        if self is McpServerName.ELEVEN_LABS:
            return eleven_labs()
        if self is McpServerName.EXA:
            return exa()
        if self is McpServerName.FATHOM:
            return fathom()
        if self is McpServerName.FIGMA:
            return figma()
        if self is McpServerName.FIREFLIES:
            return fireflies()
        if self is McpServerName.FIRECRAWL_DEEP_RESEARCH:
            return firecrawl_deep_research()
        if self is McpServerName.FIRECRAWL_WEB_SEARCH:
            return firecrawl_web_search()
        if self is McpServerName.FRESHDESK:
            return freshdesk()
        if self is McpServerName.GITHUB:
            return github()
        if self is McpServerName.GITLAB:
            return gitlab()
        if self is McpServerName.GMAIL:
            return gmail()
        if self is McpServerName.GONG:
            return gong()
        if self is McpServerName.GOOGLE_CALENDAR:
            return google_calendar()
        if self is McpServerName.GOOGLE_DOCS:
            return google_docs()
        if self is McpServerName.GOOGLE_DRIVE:
            return google_drive()
        if self is McpServerName.GOOGLE_JOBS:
            return google_jobs()
        if self is McpServerName.GOOGLE_SHEETS:
            return google_sheets()
        if self is McpServerName.GOOGLE_FORMS:
            return google_forms()
        if self is McpServerName.GOOGLE_CLOUD:
            return google_cloud()
        if self is McpServerName.HACKER_NEWS:
            return hacker_news()
        if self is McpServerName.HEYGEN:
            return heygen()
        if self is McpServerName.HUBSPOT:
            return hubspot()
        if self is McpServerName.JIRA:
            return jira()
        if self is McpServerName.KLAVIYO:
            return klaviyo()
        if self is McpServerName.KLAVIS_REPORT_GEN:
            return klavis_report_gen()
        if self is McpServerName.LINEAR:
            return linear()
        if self is McpServerName.LINKEDIN:
            return linkedin()
        if self is McpServerName.MARKDOWN2DOC:
            return markdown2doc()
        if self is McpServerName.MEM0:
            return mem0()
        if self is McpServerName.MICROSOFT_TEAMS:
            return microsoft_teams()
        if self is McpServerName.MIXPANEL:
            return mixpanel()
        if self is McpServerName.MONDAY:
            return monday()
        if self is McpServerName.MONEYBIRD:
            return moneybird()
        if self is McpServerName.MOTION:
            return motion()
        if self is McpServerName.NOTION:
            return notion()
        if self is McpServerName.ONEDRIVE:
            return onedrive()
        if self is McpServerName.OPENROUTER:
            return openrouter()
        if self is McpServerName.OUTLOOK_MAIL:
            return outlook_mail()
        if self is McpServerName.OUTLOOK_CALENDAR:
            return outlook_calendar()
        if self is McpServerName.PAGERDUTY:
            return pagerduty()
        if self is McpServerName.PIPEDRIVE:
            return pipedrive()
        if self is McpServerName.PLAI:
            return plai()
        if self is McpServerName.POSTGRES:
            return postgres()
        if self is McpServerName.POSTHOG:
            return posthog()
        if self is McpServerName.POSTMAN:
            return postman()
        if self is McpServerName.QUICKBOOKS:
            return quickbooks()
        if self is McpServerName.RESEND:
            return resend()
        if self is McpServerName.SALESFORCE:
            return salesforce()
        if self is McpServerName.SENDGRID:
            return sendgrid()
        if self is McpServerName.SHOPIFY:
            return shopify()
        if self is McpServerName.SLACK:
            return slack()
        if self is McpServerName.SNOWFLAKE:
            return snowflake()
        if self is McpServerName.STRIPE:
            return stripe()
        if self is McpServerName.SUPABASE:
            return supabase()
        if self is McpServerName.TAVILY:
            return tavily()
        if self is McpServerName.VERCEL:
            return vercel()
        if self is McpServerName.WHATSAPP:
            return whatsapp()
        if self is McpServerName.WORDPRESS:
            return wordpress()
        if self is McpServerName.YOUTUBE:
            return youtube()
        if self is McpServerName.ZENDESK:
            return zendesk()
        if self is McpServerName.SERVICE_NOW:
            return service_now()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GitHubPullRequest(UniversalBaseModel):
    """
    GitHub Pull Request object
    """

    id: typing.Optional[int] = pydantic.Field(default=None)
    """
    PR ID (read-only, set by GitHub)
    """

    title: str = pydantic.Field()
    """
    Pull request title
    """

    body: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pull request description/body
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    PR state: open, closed, or merged
    """

    head: str = pydantic.Field()
    """
    Head branch name
    """

    base: typing.Optional[str] = pydantic.Field(default=None)
    """
    Base branch name
    """

    labels: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of label names
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AirtableDataOutput,
        AirtableField,
        AirtableRecord,
        AirtableTable,
        ApiKeyAuth,
        AsanaDataOutput,
        AsanaProject,
        AsanaStory,
        AsanaTask,
        AzureAdoAuthErrorResponse,
        AzureAdoAuthSuccessResponse,
        BigQueryDataset,
        BigQueryDatasetReference,
        BigQueryTable,
        BigQueryTableFieldSchema,
        BigQueryTableReference,
        BigQueryTableSchema,
        CalcomData,
        CalcomSchedule,
        CallToolResponse,
        CallToolResult,
        ClickUpComment,
        ClickUpDataOutput,
        ClickUpFolder,
        ClickUpList,
        ClickUpSpace,
        ClickUpTask,
        CloseContact,
        CloseDataOutput,
        CloseLead,
        CloseOpportunity,
        CloseTask,
        ComputeInstance,
        ConfluenceComment,
        ConfluenceDataOutput,
        ConfluencePage,
        ConfluencePageOutput,
        ConfluenceSpace,
        ConnectionType,
        CreateSandboxResponse,
        CreateSelfHostedServerResponse,
        CreateServerResponse,
        DeleteUserResponse,
        DiscordChannel,
        DiscordDataOutput,
        DiscordMessage,
        DiscordReaction,
        DropboxData,
        DropboxFile,
        DumpSandboxResponseAirtableData,
        DumpSandboxResponseAsanaData,
        DumpSandboxResponseCalcomData,
        DumpSandboxResponseClickUpData,
        DumpSandboxResponseCloseData,
        DumpSandboxResponseConfluenceData,
        DumpSandboxResponseDiscordData,
        DumpSandboxResponseDropboxData,
        DumpSandboxResponseGitHubData,
        DumpSandboxResponseGmailData,
        DumpSandboxResponseGoogleCalendarData,
        DumpSandboxResponseGoogleCloudData,
        DumpSandboxResponseGoogleDocsData,
        DumpSandboxResponseGoogleDriveData,
        DumpSandboxResponseGoogleFormsData,
        DumpSandboxResponseGoogleSheetsData,
        DumpSandboxResponseHubSpotData,
        DumpSandboxResponseJiraData,
        DumpSandboxResponseLinearData,
        DumpSandboxResponseMem0Data,
        DumpSandboxResponseMoneybirdData,
        DumpSandboxResponseMsTeamsData,
        DumpSandboxResponseNotionData,
        DumpSandboxResponseOneDriveData,
        DumpSandboxResponseOutlookCalendarData,
        DumpSandboxResponseOutlookMailData,
        DumpSandboxResponseQuickBooksData,
        DumpSandboxResponseResendData,
        DumpSandboxResponseSalesforceData,
        DumpSandboxResponseShopifyData,
        DumpSandboxResponseSlackData,
        DumpSandboxResponseSnowflakeData,
        DumpSandboxResponseSupabaseData,
        DumpSandboxResponseWordPressData,
        ExternalServerInfo,
        ExternalServerRequest,
        GeneralAuth,
        GetAllUsersResponse,
        GetAuthDataResponse,
        GetInstanceResponse,
        GetMcpServersResponse,
        GetUserAuthResponse,
        GetUserIntegrationsResponse,
        GetUserResponse,
        GitHubBranch,
        GitHubData,
        GitHubFile,
        GitHubFolder,
        GitHubIssue,
        GitHubPullRequest,
        GitHubRepo,
        GmailData,
        GmailDraft,
        GmailMessage,
        GoogleCalendarAttendee,
        GoogleCalendarData,
        GoogleCalendarEvent,
        GoogleCalendarEventDateTime,
        GoogleCloudDataOutput,
        GoogleDocsData,
        GoogleDocsDocument,
        GoogleDriveData,
        GoogleDriveFile,
        GoogleFormsData,
        GoogleFormsForm,
        GoogleFormsFormSettings,
        GoogleFormsInfo,
        GoogleFormsItem,
        GoogleFormsQuizSettings,
        GoogleSheetsCellValue,
        GoogleSheetsData,
        GoogleSheetsGridData,
        GoogleSheetsRowData,
        GoogleSheetsSheet,
        GoogleSheetsSheetProperties,
        GoogleSheetsSpreadsheet,
        GoogleSheetsSpreadsheetProperties,
        HttpValidationError,
        HubSpotCompany,
        HubSpotContact,
        HubSpotDataOutput,
        HubSpotDeal,
        HubSpotTask,
        HubSpotTicket,
        InitializeSandboxResponse,
        JiraBoard,
        JiraComment,
        JiraDataOutput,
        JiraIssue,
        JiraProject,
        JiraSprint,
        LinearComment,
        LinearData,
        LinearIssue,
        LinearProject,
        ListToolsResponse,
        LogBucket,
        LogEntry,
        LogSink,
        McpServer,
        McpServerName,
        Mem0DataOutput,
        Mem0Memory,
        Mem0Message,
        MoneybirdContact,
        MoneybirdData,
        MoneybirdInvoiceDetail,
        MoneybirdLedgerAccount,
        MoneybirdProduct,
        MoneybirdProject,
        MoneybirdSalesInvoice,
        MoneybirdTimeEntry,
        MsTeamsData,
        NotionBlock,
        NotionComment,
        NotionDataOutput,
        NotionDataSource,
        NotionDatabase,
        NotionPage,
        OAuthServerName,
        OneDriveData,
        OneDriveFile,
        OneDriveFolder,
        OutlookCalendarData,
        OutlookCalendarEvent,
        OutlookMailData,
        OutlookMailMessage,
        Override,
        QuickBooksData,
        RawActionsResponse,
        ReleaseSandboxResponse,
        ResendBroadcast,
        ResendContact,
        ResendDataOutput,
        ResendEmail,
        ResendSegment,
        ResetSandboxResponse,
        SalesforceAccount,
        SalesforceCampaign,
        SalesforceCase,
        SalesforceContact,
        SalesforceData,
        SalesforceLead,
        SalesforceOpportunity,
        SandboxInfo,
        SandboxMcpServer,
        SandboxStatus,
        ServerTool,
        SharesightOAuthErrorResponse,
        SharesightOAuthSuccessResponse,
        ShopifyAddress,
        ShopifyCustomer,
        ShopifyData,
        ShopifyProduct,
        ShopifyProductVariant,
        SlackChannel,
        SlackDataOutput,
        SlackMessage,
        SlackMessageOutput,
        SlackReaction,
        SnowflakeColumn,
        SnowflakeDataOutput,
        SnowflakeDatabase,
        SnowflakeRow,
        SnowflakeSchema,
        SnowflakeTable,
        StatusResponse,
        StorageBucket,
        StorageBucketLifecycle,
        StorageBucketLifecycleRule,
        StorageBucketLifecycleRuleAction,
        StorageBucketLifecycleRuleCondition,
        StorageBucketVersioning,
        StorageObject,
        StrataAddServersResponse,
        StrataCreateResponse,
        StrataDeleteServersResponse,
        StrataGetAuthResponse,
        StrataGetResponse,
        StrataRawActionsResponse,
        SupabaseData,
        SupabaseProject,
        SupabaseTable,
        TeamsChannel,
        TeamsChat,
        TeamsChatMember,
        TeamsMessage,
        TimeSlot,
        ToolFormat,
        UserInfo,
        ValidationError,
        ValidationErrorLocItem,
        WhiteLabelingResponse,
        WordPressData,
        WordPressPost,
        ZoomOAuthErrorResponse,
        ZoomOAuthSuccessResponse,
    )
    from .errors import BadRequestError, UnprocessableEntityError
    from . import (
        mcp_server,
        mscalendar_oauth,
        oauth,
        onedrive_oauth,
        outlook_oauth,
        sandbox,
        sharesight_oauth,
        teams_oauth,
        user,
        white_labeling,
        zoho_mail_oauth,
        zoom_oauth,
    )
    from .client import AsyncKlavis, Klavis
    from .environment import KlavisEnvironment
    from .mcp_server import (
        Authdata,
        DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem,
        Servers,
        SetAuthRequestAuthData,
    )
    from .oauth import Environment
    from .user import SetUserAuthRequestAuthData
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AirtableDataOutput": ".types",
    "AirtableField": ".types",
    "AirtableRecord": ".types",
    "AirtableTable": ".types",
    "ApiKeyAuth": ".types",
    "AsanaDataOutput": ".types",
    "AsanaProject": ".types",
    "AsanaStory": ".types",
    "AsanaTask": ".types",
    "AsyncKlavis": ".client",
    "Authdata": ".mcp_server",
    "AzureAdoAuthErrorResponse": ".types",
    "AzureAdoAuthSuccessResponse": ".types",
    "BadRequestError": ".errors",
    "BigQueryDataset": ".types",
    "BigQueryDatasetReference": ".types",
    "BigQueryTable": ".types",
    "BigQueryTableFieldSchema": ".types",
    "BigQueryTableReference": ".types",
    "BigQueryTableSchema": ".types",
    "CalcomData": ".types",
    "CalcomSchedule": ".types",
    "CallToolResponse": ".types",
    "CallToolResult": ".types",
    "ClickUpComment": ".types",
    "ClickUpDataOutput": ".types",
    "ClickUpFolder": ".types",
    "ClickUpList": ".types",
    "ClickUpSpace": ".types",
    "ClickUpTask": ".types",
    "CloseContact": ".types",
    "CloseDataOutput": ".types",
    "CloseLead": ".types",
    "CloseOpportunity": ".types",
    "CloseTask": ".types",
    "ComputeInstance": ".types",
    "ConfluenceComment": ".types",
    "ConfluenceDataOutput": ".types",
    "ConfluencePage": ".types",
    "ConfluencePageOutput": ".types",
    "ConfluenceSpace": ".types",
    "ConnectionType": ".types",
    "CreateSandboxResponse": ".types",
    "CreateSelfHostedServerResponse": ".types",
    "CreateServerResponse": ".types",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem": ".mcp_server",
    "DeleteUserResponse": ".types",
    "DiscordChannel": ".types",
    "DiscordDataOutput": ".types",
    "DiscordMessage": ".types",
    "DiscordReaction": ".types",
    "DropboxData": ".types",
    "DropboxFile": ".types",
    "DumpSandboxResponseAirtableData": ".types",
    "DumpSandboxResponseAsanaData": ".types",
    "DumpSandboxResponseCalcomData": ".types",
    "DumpSandboxResponseClickUpData": ".types",
    "DumpSandboxResponseCloseData": ".types",
    "DumpSandboxResponseConfluenceData": ".types",
    "DumpSandboxResponseDiscordData": ".types",
    "DumpSandboxResponseDropboxData": ".types",
    "DumpSandboxResponseGitHubData": ".types",
    "DumpSandboxResponseGmailData": ".types",
    "DumpSandboxResponseGoogleCalendarData": ".types",
    "DumpSandboxResponseGoogleCloudData": ".types",
    "DumpSandboxResponseGoogleDocsData": ".types",
    "DumpSandboxResponseGoogleDriveData": ".types",
    "DumpSandboxResponseGoogleFormsData": ".types",
    "DumpSandboxResponseGoogleSheetsData": ".types",
    "DumpSandboxResponseHubSpotData": ".types",
    "DumpSandboxResponseJiraData": ".types",
    "DumpSandboxResponseLinearData": ".types",
    "DumpSandboxResponseMem0Data": ".types",
    "DumpSandboxResponseMoneybirdData": ".types",
    "DumpSandboxResponseMsTeamsData": ".types",
    "DumpSandboxResponseNotionData": ".types",
    "DumpSandboxResponseOneDriveData": ".types",
    "DumpSandboxResponseOutlookCalendarData": ".types",
    "DumpSandboxResponseOutlookMailData": ".types",
    "DumpSandboxResponseQuickBooksData": ".types",
    "DumpSandboxResponseResendData": ".types",
    "DumpSandboxResponseSalesforceData": ".types",
    "DumpSandboxResponseShopifyData": ".types",
    "DumpSandboxResponseSlackData": ".types",
    "DumpSandboxResponseSnowflakeData": ".types",
    "DumpSandboxResponseSupabaseData": ".types",
    "DumpSandboxResponseWordPressData": ".types",
    "Environment": ".oauth",
    "ExternalServerInfo": ".types",
    "ExternalServerRequest": ".types",
    "GeneralAuth": ".types",
    "GetAllUsersResponse": ".types",
    "GetAuthDataResponse": ".types",
    "GetInstanceResponse": ".types",
    "GetMcpServersResponse": ".types",
    "GetUserAuthResponse": ".types",
    "GetUserIntegrationsResponse": ".types",
    "GetUserResponse": ".types",
    "GitHubBranch": ".types",
    "GitHubData": ".types",
    "GitHubFile": ".types",
    "GitHubFolder": ".types",
    "GitHubIssue": ".types",
    "GitHubPullRequest": ".types",
    "GitHubRepo": ".types",
    "GmailData": ".types",
    "GmailDraft": ".types",
    "GmailMessage": ".types",
    "GoogleCalendarAttendee": ".types",
    "GoogleCalendarData": ".types",
    "GoogleCalendarEvent": ".types",
    "GoogleCalendarEventDateTime": ".types",
    "GoogleCloudDataOutput": ".types",
    "GoogleDocsData": ".types",
    "GoogleDocsDocument": ".types",
    "GoogleDriveData": ".types",
    "GoogleDriveFile": ".types",
    "GoogleFormsData": ".types",
    "GoogleFormsForm": ".types",
    "GoogleFormsFormSettings": ".types",
    "GoogleFormsInfo": ".types",
    "GoogleFormsItem": ".types",
    "GoogleFormsQuizSettings": ".types",
    "GoogleSheetsCellValue": ".types",
    "GoogleSheetsData": ".types",
    "GoogleSheetsGridData": ".types",
    "GoogleSheetsRowData": ".types",
    "GoogleSheetsSheet": ".types",
    "GoogleSheetsSheetProperties": ".types",
    "GoogleSheetsSpreadsheet": ".types",
    "GoogleSheetsSpreadsheetProperties": ".types",
    "HttpValidationError": ".types",
    "HubSpotCompany": ".types",
    "HubSpotContact": ".types",
    "HubSpotDataOutput": ".types",
    "HubSpotDeal": ".types",
    "HubSpotTask": ".types",
    "HubSpotTicket": ".types",
    "InitializeSandboxResponse": ".types",
    "JiraBoard": ".types",
    "JiraComment": ".types",
    "JiraDataOutput": ".types",
    "JiraIssue": ".types",
    "JiraProject": ".types",
    "JiraSprint": ".types",
    "Klavis": ".client",
    "KlavisEnvironment": ".environment",
    "LinearComment": ".types",
    "LinearData": ".types",
    "LinearIssue": ".types",
    "LinearProject": ".types",
    "ListToolsResponse": ".types",
    "LogBucket": ".types",
    "LogEntry": ".types",
    "LogSink": ".types",
    "McpServer": ".types",
    "McpServerName": ".types",
    "Mem0DataOutput": ".types",
    "Mem0Memory": ".types",
    "Mem0Message": ".types",
    "MoneybirdContact": ".types",
    "MoneybirdData": ".types",
    "MoneybirdInvoiceDetail": ".types",
    "MoneybirdLedgerAccount": ".types",
    "MoneybirdProduct": ".types",
    "MoneybirdProject": ".types",
    "MoneybirdSalesInvoice": ".types",
    "MoneybirdTimeEntry": ".types",
    "MsTeamsData": ".types",
    "NotionBlock": ".types",
    "NotionComment": ".types",
    "NotionDataOutput": ".types",
    "NotionDataSource": ".types",
    "NotionDatabase": ".types",
    "NotionPage": ".types",
    "OAuthServerName": ".types",
    "OneDriveData": ".types",
    "OneDriveFile": ".types",
    "OneDriveFolder": ".types",
    "OutlookCalendarData": ".types",
    "OutlookCalendarEvent": ".types",
    "OutlookMailData": ".types",
    "OutlookMailMessage": ".types",
    "Override": ".types",
    "QuickBooksData": ".types",
    "RawActionsResponse": ".types",
    "ReleaseSandboxResponse": ".types",
    "ResendBroadcast": ".types",
    "ResendContact": ".types",
    "ResendDataOutput": ".types",
    "ResendEmail": ".types",
    "ResendSegment": ".types",
    "ResetSandboxResponse": ".types",
    "SalesforceAccount": ".types",
    "SalesforceCampaign": ".types",
    "SalesforceCase": ".types",
    "SalesforceContact": ".types",
    "SalesforceData": ".types",
    "SalesforceLead": ".types",
    "SalesforceOpportunity": ".types",
    "SandboxInfo": ".types",
    "SandboxMcpServer": ".types",
    "SandboxStatus": ".types",
    "ServerTool": ".types",
    "Servers": ".mcp_server",
    "SetAuthRequestAuthData": ".mcp_server",
    "SetUserAuthRequestAuthData": ".user",
    "SharesightOAuthErrorResponse": ".types",
    "SharesightOAuthSuccessResponse": ".types",
    "ShopifyAddress": ".types",
    "ShopifyCustomer": ".types",
    "ShopifyData": ".types",
    "ShopifyProduct": ".types",
    "ShopifyProductVariant": ".types",
    "SlackChannel": ".types",
    "SlackDataOutput": ".types",
    "SlackMessage": ".types",
    "SlackMessageOutput": ".types",
    "SlackReaction": ".types",
    "SnowflakeColumn": ".types",
    "SnowflakeDataOutput": ".types",
    "SnowflakeDatabase": ".types",
    "SnowflakeRow": ".types",
    "SnowflakeSchema": ".types",
    "SnowflakeTable": ".types",
    "StatusResponse": ".types",
    "StorageBucket": ".types",
    "StorageBucketLifecycle": ".types",
    "StorageBucketLifecycleRule": ".types",
    "StorageBucketLifecycleRuleAction": ".types",
    "StorageBucketLifecycleRuleCondition": ".types",
    "StorageBucketVersioning": ".types",
    "StorageObject": ".types",
    "StrataAddServersResponse": ".types",
    "StrataCreateResponse": ".types",
    "StrataDeleteServersResponse": ".types",
    "StrataGetAuthResponse": ".types",
    "StrataGetResponse": ".types",
    "StrataRawActionsResponse": ".types",
    "SupabaseData": ".types",
    "SupabaseProject": ".types",
    "SupabaseTable": ".types",
    "TeamsChannel": ".types",
    "TeamsChat": ".types",
    "TeamsChatMember": ".types",
    "TeamsMessage": ".types",
    "TimeSlot": ".types",
    "ToolFormat": ".types",
    "UnprocessableEntityError": ".errors",
    "UserInfo": ".types",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "WhiteLabelingResponse": ".types",
    "WordPressData": ".types",
    "WordPressPost": ".types",
    "ZoomOAuthErrorResponse": ".types",
    "ZoomOAuthSuccessResponse": ".types",
    "__version__": ".version",
    "mcp_server": ".mcp_server",
    "mscalendar_oauth": ".mscalendar_oauth",
    "oauth": ".oauth",
    "onedrive_oauth": ".onedrive_oauth",
    "outlook_oauth": ".outlook_oauth",
    "sandbox": ".sandbox",
    "sharesight_oauth": ".sharesight_oauth",
    "teams_oauth": ".teams_oauth",
    "user": ".user",
    "white_labeling": ".white_labeling",
    "zoho_mail_oauth": ".zoho_mail_oauth",
    "zoom_oauth": ".zoom_oauth",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AirtableDataOutput",
    "AirtableField",
    "AirtableRecord",
    "AirtableTable",
    "ApiKeyAuth",
    "AsanaDataOutput",
    "AsanaProject",
    "AsanaStory",
    "AsanaTask",
    "AsyncKlavis",
    "Authdata",
    "AzureAdoAuthErrorResponse",
    "AzureAdoAuthSuccessResponse",
    "BadRequestError",
    "BigQueryDataset",
    "BigQueryDatasetReference",
    "BigQueryTable",
    "BigQueryTableFieldSchema",
    "BigQueryTableReference",
    "BigQueryTableSchema",
    "CalcomData",
    "CalcomSchedule",
    "CallToolResponse",
    "CallToolResult",
    "ClickUpComment",
    "ClickUpDataOutput",
    "ClickUpFolder",
    "ClickUpList",
    "ClickUpSpace",
    "ClickUpTask",
    "CloseContact",
    "CloseDataOutput",
    "CloseLead",
    "CloseOpportunity",
    "CloseTask",
    "ComputeInstance",
    "ConfluenceComment",
    "ConfluenceDataOutput",
    "ConfluencePage",
    "ConfluencePageOutput",
    "ConfluenceSpace",
    "ConnectionType",
    "CreateSandboxResponse",
    "CreateSelfHostedServerResponse",
    "CreateServerResponse",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem",
    "DeleteUserResponse",
    "DiscordChannel",
    "DiscordDataOutput",
    "DiscordMessage",
    "DiscordReaction",
    "DropboxData",
    "DropboxFile",
    "DumpSandboxResponseAirtableData",
    "DumpSandboxResponseAsanaData",
    "DumpSandboxResponseCalcomData",
    "DumpSandboxResponseClickUpData",
    "DumpSandboxResponseCloseData",
    "DumpSandboxResponseConfluenceData",
    "DumpSandboxResponseDiscordData",
    "DumpSandboxResponseDropboxData",
    "DumpSandboxResponseGitHubData",
    "DumpSandboxResponseGmailData",
    "DumpSandboxResponseGoogleCalendarData",
    "DumpSandboxResponseGoogleCloudData",
    "DumpSandboxResponseGoogleDocsData",
    "DumpSandboxResponseGoogleDriveData",
    "DumpSandboxResponseGoogleFormsData",
    "DumpSandboxResponseGoogleSheetsData",
    "DumpSandboxResponseHubSpotData",
    "DumpSandboxResponseJiraData",
    "DumpSandboxResponseLinearData",
    "DumpSandboxResponseMem0Data",
    "DumpSandboxResponseMoneybirdData",
    "DumpSandboxResponseMsTeamsData",
    "DumpSandboxResponseNotionData",
    "DumpSandboxResponseOneDriveData",
    "DumpSandboxResponseOutlookCalendarData",
    "DumpSandboxResponseOutlookMailData",
    "DumpSandboxResponseQuickBooksData",
    "DumpSandboxResponseResendData",
    "DumpSandboxResponseSalesforceData",
    "DumpSandboxResponseShopifyData",
    "DumpSandboxResponseSlackData",
    "DumpSandboxResponseSnowflakeData",
    "DumpSandboxResponseSupabaseData",
    "DumpSandboxResponseWordPressData",
    "Environment",
    "ExternalServerInfo",
    "ExternalServerRequest",
    "GeneralAuth",
    "GetAllUsersResponse",
    "GetAuthDataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetUserAuthResponse",
    "GetUserIntegrationsResponse",
    "GetUserResponse",
    "GitHubBranch",
    "GitHubData",
    "GitHubFile",
    "GitHubFolder",
    "GitHubIssue",
    "GitHubPullRequest",
    "GitHubRepo",
    "GmailData",
    "GmailDraft",
    "GmailMessage",
    "GoogleCalendarAttendee",
    "GoogleCalendarData",
    "GoogleCalendarEvent",
    "GoogleCalendarEventDateTime",
    "GoogleCloudDataOutput",
    "GoogleDocsData",
    "GoogleDocsDocument",
    "GoogleDriveData",
    "GoogleDriveFile",
    "GoogleFormsData",
    "GoogleFormsForm",
    "GoogleFormsFormSettings",
    "GoogleFormsInfo",
    "GoogleFormsItem",
    "GoogleFormsQuizSettings",
    "GoogleSheetsCellValue",
    "GoogleSheetsData",
    "GoogleSheetsGridData",
    "GoogleSheetsRowData",
    "GoogleSheetsSheet",
    "GoogleSheetsSheetProperties",
    "GoogleSheetsSpreadsheet",
    "GoogleSheetsSpreadsheetProperties",
    "HttpValidationError",
    "HubSpotCompany",
    "HubSpotContact",
    "HubSpotDataOutput",
    "HubSpotDeal",
    "HubSpotTask",
    "HubSpotTicket",
    "InitializeSandboxResponse",
    "JiraBoard",
    "JiraComment",
    "JiraDataOutput",
    "JiraIssue",
    "JiraProject",
    "JiraSprint",
    "Klavis",
    "KlavisEnvironment",
    "LinearComment",
    "LinearData",
    "LinearIssue",
    "LinearProject",
    "ListToolsResponse",
    "LogBucket",
    "LogEntry",
    "LogSink",
    "McpServer",
    "McpServerName",
    "Mem0DataOutput",
    "Mem0Memory",
    "Mem0Message",
    "MoneybirdContact",
    "MoneybirdData",
    "MoneybirdInvoiceDetail",
    "MoneybirdLedgerAccount",
    "MoneybirdProduct",
    "MoneybirdProject",
    "MoneybirdSalesInvoice",
    "MoneybirdTimeEntry",
    "MsTeamsData",
    "NotionBlock",
    "NotionComment",
    "NotionDataOutput",
    "NotionDataSource",
    "NotionDatabase",
    "NotionPage",
    "OAuthServerName",
    "OneDriveData",
    "OneDriveFile",
    "OneDriveFolder",
    "OutlookCalendarData",
    "OutlookCalendarEvent",
    "OutlookMailData",
    "OutlookMailMessage",
    "Override",
    "QuickBooksData",
    "RawActionsResponse",
    "ReleaseSandboxResponse",
    "ResendBroadcast",
    "ResendContact",
    "ResendDataOutput",
    "ResendEmail",
    "ResendSegment",
    "ResetSandboxResponse",
    "SalesforceAccount",
    "SalesforceCampaign",
    "SalesforceCase",
    "SalesforceContact",
    "SalesforceData",
    "SalesforceLead",
    "SalesforceOpportunity",
    "SandboxInfo",
    "SandboxMcpServer",
    "SandboxStatus",
    "ServerTool",
    "Servers",
    "SetAuthRequestAuthData",
    "SetUserAuthRequestAuthData",
    "SharesightOAuthErrorResponse",
    "SharesightOAuthSuccessResponse",
    "ShopifyAddress",
    "ShopifyCustomer",
    "ShopifyData",
    "ShopifyProduct",
    "ShopifyProductVariant",
    "SlackChannel",
    "SlackDataOutput",
    "SlackMessage",
    "SlackMessageOutput",
    "SlackReaction",
    "SnowflakeColumn",
    "SnowflakeDataOutput",
    "SnowflakeDatabase",
    "SnowflakeRow",
    "SnowflakeSchema",
    "SnowflakeTable",
    "StatusResponse",
    "StorageBucket",
    "StorageBucketLifecycle",
    "StorageBucketLifecycleRule",
    "StorageBucketLifecycleRuleAction",
    "StorageBucketLifecycleRuleCondition",
    "StorageBucketVersioning",
    "StorageObject",
    "StrataAddServersResponse",
    "StrataCreateResponse",
    "StrataDeleteServersResponse",
    "StrataGetAuthResponse",
    "StrataGetResponse",
    "StrataRawActionsResponse",
    "SupabaseData",
    "SupabaseProject",
    "SupabaseTable",
    "TeamsChannel",
    "TeamsChat",
    "TeamsChatMember",
    "TeamsMessage",
    "TimeSlot",
    "ToolFormat",
    "UnprocessableEntityError",
    "UserInfo",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "WordPressData",
    "WordPressPost",
    "ZoomOAuthErrorResponse",
    "ZoomOAuthSuccessResponse",
    "__version__",
    "mcp_server",
    "mscalendar_oauth",
    "oauth",
    "onedrive_oauth",
    "outlook_oauth",
    "sandbox",
    "sharesight_oauth",
    "teams_oauth",
    "user",
    "white_labeling",
    "zoho_mail_oauth",
    "zoom_oauth",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .external_server_info import ExternalServerInfo


class StrataCreateResponse(UniversalBaseModel):
    strata_server_url: typing_extensions.Annotated[str, FieldMetadata(alias="strataServerUrl")] = pydantic.Field()
    """
    URL to connect to the Strata MCP server
    """

    strata_id: typing_extensions.Annotated[str, FieldMetadata(alias="strataId")] = pydantic.Field()
    """
    The strata server ID
    """

    added_servers: typing_extensions.Annotated[typing.List[str], FieldMetadata(alias="addedServers")] = pydantic.Field()
    """
    List of Klavis integration that were added
    """

    added_external_servers: typing_extensions.Annotated[
        typing.Optional[typing.List[ExternalServerInfo]], FieldMetadata(alias="addedExternalServers")
    ] = pydantic.Field(default=None)
    """
    List of external MCP servers that were added with name and URL
    """

    oauth_urls: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, str]], FieldMetadata(alias="oauthUrls")
    ] = pydantic.Field(default=None)
    """
    Map of connected integration to OAuth URL, supports white labeling if configured
    """

    api_key_urls: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, str]], FieldMetadata(alias="apiKeyUrls")
    ] = pydantic.Field(default=None)
    """
    Map of connected integration to API key setup URL
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .teams_channel import TeamsChannel
from .teams_chat import TeamsChat


class MsTeamsData(UniversalBaseModel):
    """
    Complete Microsoft Teams sandbox data structure
    """

    channels: typing.Optional[typing.List[TeamsChannel]] = pydantic.Field(default=None)
    """
    List of team channels
    """

    chats: typing.Optional[typing.List[TeamsChat]] = pydantic.Field(default=None)
    """
    List of one-on-one chats
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .google_calendar_attendee import GoogleCalendarAttendee
from .google_calendar_event_date_time import GoogleCalendarEventDateTime


class GoogleCalendarEvent(UniversalBaseModel):
    """
    Google Calendar event object
    """

    summary: str = pydantic.Field()
    """
    Event title/summary (required)
    """

    start: GoogleCalendarEventDateTime = pydantic.Field()
    """
    Event start time (required)
    """

    end: GoogleCalendarEventDateTime = pydantic.Field()
    """
    Event end time (required)
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Event description
    """

    location: typing.Optional[str] = pydantic.Field(default=None)
    """
    Event location
    """

    attendees: typing.Optional[typing.List[GoogleCalendarAttendee]] = pydantic.Field(default=None)
    """
    List of event attendees
    """

    color_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="colorId")] = pydantic.Field(
        default=None
    )
    """
    Event color (1-11)
    """

    visibility: typing.Optional[str] = pydantic.Field(default=None)
    """
    Visibility (default, public, private, confidential)
    """

    transparency: typing.Optional[str] = pydantic.Field(default=None)
    """
    Transparency (opaque, transparent)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ResendEmail(UniversalBaseModel):
    """
    Resend Email object - standalone transactional email
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Email ID (read-only, set by Resend)
    """

    from_: typing_extensions.Annotated[str, FieldMetadata(alias="from")] = pydantic.Field()
    """
    Sender email address
    """

    to: typing.List[str] = pydantic.Field()
    """
    Recipient email addresses
    """

    subject: str = pydantic.Field()
    """
    Email subject
    """

    html: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTML content of the email
    """

    text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Plain text content of the email
    """

    reply_to: typing.Optional[str] = pydantic.Field(default=None)
    """
    Reply-to email address
    """

    cc: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    CC email addresses
    """

    bcc: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    BCC email addresses
    """

    tags: typing.Optional[typing.List[typing.Dict[str, str]]] = pydantic.Field(default=None)
    """
    Email tags for categorization
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    Creation timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class MoneybirdTimeEntry(UniversalBaseModel):
    """
    Moneybird time entry - API format

    Note: During initialization, this will be linked to a project and contact automatically.
    The started_at and ended_at timestamps will be generated based on the hours field.

    Attributes:
        description: Description of work performed
        hours: Number of hours worked
        billable: Whether this time is billable
    """

    description: str = pydantic.Field()
    """
    Description of work performed
    """

    hours: float = pydantic.Field()
    """
    Number of hours worked
    """

    billable: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether this time is billable
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ResendContact(UniversalBaseModel):
    """
    Resend Contact object - standalone, independent of segments
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Contact ID (read-only, set by Resend)
    """

    email: str = pydantic.Field()
    """
    The email address of the contact.
    """

    first_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Contact first name
    """

    last_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Contact last name
    """

    unsubscribed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether contact is unsubscribed from all Broadcasts
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    Creation timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .discord_message import DiscordMessage


class DiscordChannel(UniversalBaseModel):
    """
    Discord Channel - uses existing channel by ID
    """

    channel_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Discord channel ID (auto-discovered if not provided)
    """

    messages: typing.Optional[typing.List[DiscordMessage]] = pydantic.Field(default=None)
    """
    Messages in this channel
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SandboxStatus(str, enum.Enum):
    """
    Status of a sandbox instance - matches database enum
    """

    IDLE = "idle"
    OCCUPIED = "occupied"

    def visit(self, idle: typing.Callable[[], T_Result], occupied: typing.Callable[[], T_Result]) -> T_Result:
        if self is SandboxStatus.IDLE:
            return idle()
        if self is SandboxStatus.OCCUPIED:
            return occupied()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .google_forms_quiz_settings import GoogleFormsQuizSettings


class GoogleFormsFormSettings(UniversalBaseModel):
    """
    Form settings - matches API FormSettings object
    """

    quiz_settings: typing_extensions.Annotated[
        typing.Optional[GoogleFormsQuizSettings], FieldMetadata(alias="quizSettings")
    ] = pydantic.Field(default=None)
    """
    Settings related to quiz forms
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class JiraSprint(UniversalBaseModel):
    """
    Jira Sprint object
    """

    name: str = pydantic.Field()
    """
    Sprint name
    """

    start_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sprint start date (ISO 8601 format)
    """

    end_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sprint end date (ISO 8601 format)
    """

    origin_board_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the board this sprint belongs to (for initialization)
    """

    goal: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sprint goal
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Sprint state (future, active, closed)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SalesforceCampaign(UniversalBaseModel):
    """
    Salesforce Campaign object
    """

    name: typing_extensions.Annotated[str, FieldMetadata(alias="Name")] = pydantic.Field()
    """
    Campaign name (required)
    """

    type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Type")] = pydantic.Field(default=None)
    """
    Campaign type (e.g., Email, Webinar, Conference)
    """

    status: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Status")] = pydantic.Field(
        default=None
    )
    """
    Campaign status (e.g., Planned, In Progress, Completed)
    """

    start_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="StartDate")] = pydantic.Field(
        default=None
    )
    """
    Start date (format: YYYY-MM-DD)
    """

    end_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="EndDate")] = pydantic.Field(
        default=None
    )
    """
    End date (format: YYYY-MM-DD)
    """

    expected_revenue: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="ExpectedRevenue")] = (
        pydantic.Field(default=None)
    )
    """
    Expected revenue
    """

    budgeted_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="BudgetedCost")] = (
        pydantic.Field(default=None)
    )
    """
    Budgeted cost
    """

    actual_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="ActualCost")] = (
        pydantic.Field(default=None)
    )
    """
    Actual cost
    """

    description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Description")] = pydantic.Field(
        default=None
    )
    """
    Campaign description
    """

    is_active: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="IsActive")] = pydantic.Field(
        default=None
    )
    """
    Is campaign active
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.big_query_dataset import BigQueryDataset
from ..types.big_query_table import BigQueryTable
from ..types.compute_instance import ComputeInstance
from ..types.create_sandbox_response import CreateSandboxResponse
from ..types.dump_sandbox_response_google_cloud_data import DumpSandboxResponseGoogleCloudData
from ..types.http_validation_error import HttpValidationError
from ..types.initialize_sandbox_response import InitializeSandboxResponse
from ..types.log_bucket import LogBucket
from ..types.log_entry import LogEntry
from ..types.log_sink import LogSink
from ..types.release_sandbox_response import ReleaseSandboxResponse
from ..types.reset_sandbox_response import ResetSandboxResponse
from ..types.sandbox_info import SandboxInfo
from ..types.sandbox_mcp_server import SandboxMcpServer
from ..types.storage_bucket import StorageBucket
from ..types.storage_object import StorageObject

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawSandboxClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_sandbox(
        self, server_name: SandboxMcpServer, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CreateSandboxResponse]:
        """
        Acquire an idle sandbox instance for a specific MCP server. The sandbox will be marked as 'occupied'.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateSandboxResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateSandboxResponse,
                    parse_obj_as(
                        type_=CreateSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SandboxInfo]:
        """
        Retrieve detailed information about a specific sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SandboxInfo]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SandboxInfo,
                    parse_obj_as(
                        type_=SandboxInfo,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ReleaseSandboxResponse]:
        """
        Release an occupied sandbox back to idle state and marks the sandbox as available for reuse.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ReleaseSandboxResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ReleaseSandboxResponse,
                    parse_obj_as(
                        type_=ReleaseSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def reset_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ResetSandboxResponse]:
        """
        Reset the sandbox to its initial empty state, clearing all data while maintaining the sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ResetSandboxResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}/reset",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResetSandboxResponse,
                    parse_obj_as(
                        type_=ResetSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def initialize_sandbox(
        self,
        sandbox_id: str,
        *,
        datasets: typing.Optional[typing.Sequence[BigQueryDataset]] = OMIT,
        tables: typing.Optional[typing.Sequence[BigQueryTable]] = OMIT,
        buckets: typing.Optional[typing.Sequence[StorageBucket]] = OMIT,
        objects: typing.Optional[typing.Sequence[StorageObject]] = OMIT,
        log_entries: typing.Optional[typing.Sequence[LogEntry]] = OMIT,
        log_sinks: typing.Optional[typing.Sequence[LogSink]] = OMIT,
        log_buckets: typing.Optional[typing.Sequence[LogBucket]] = OMIT,
        instances: typing.Optional[typing.Sequence[ComputeInstance]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[InitializeSandboxResponse]:
        """
        Initialize the sandbox with google_cloud-specific data following the defined schema.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        datasets : typing.Optional[typing.Sequence[BigQueryDataset]]
            BigQuery datasets

        tables : typing.Optional[typing.Sequence[BigQueryTable]]
            BigQuery tables

        buckets : typing.Optional[typing.Sequence[StorageBucket]]
            Cloud Storage buckets

        objects : typing.Optional[typing.Sequence[StorageObject]]
            Cloud Storage objects

        log_entries : typing.Optional[typing.Sequence[LogEntry]]
            Log entries

        log_sinks : typing.Optional[typing.Sequence[LogSink]]
            Log sinks

        log_buckets : typing.Optional[typing.Sequence[LogBucket]]
            Log buckets

        instances : typing.Optional[typing.Sequence[ComputeInstance]]
            Compute Engine instances

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[InitializeSandboxResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/google_cloud/{jsonable_encoder(sandbox_id)}/initialize",
            method="POST",
            json={
                "datasets": convert_and_respect_annotation_metadata(
                    object_=datasets, annotation=typing.Sequence[BigQueryDataset], direction="write"
                ),
                "tables": convert_and_respect_annotation_metadata(
                    object_=tables, annotation=typing.Sequence[BigQueryTable], direction="write"
                ),
                "buckets": convert_and_respect_annotation_metadata(
                    object_=buckets, annotation=typing.Sequence[StorageBucket], direction="write"
                ),
                "objects": convert_and_respect_annotation_metadata(
                    object_=objects, annotation=typing.Sequence[StorageObject], direction="write"
                ),
                "logEntries": convert_and_respect_annotation_metadata(
                    object_=log_entries, annotation=typing.Sequence[LogEntry], direction="write"
                ),
                "logSinks": convert_and_respect_annotation_metadata(
                    object_=log_sinks, annotation=typing.Sequence[LogSink], direction="write"
                ),
                "logBuckets": convert_and_respect_annotation_metadata(
                    object_=log_buckets, annotation=typing.Sequence[LogBucket], direction="write"
                ),
                "instances": convert_and_respect_annotation_metadata(
                    object_=instances, annotation=typing.Sequence[ComputeInstance], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    InitializeSandboxResponse,
                    parse_obj_as(
                        type_=InitializeSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def dump_sandbox(
        self, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DumpSandboxResponseGoogleCloudData]:
        """
        Export all data from the sandbox in the same format used for initialization.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DumpSandboxResponseGoogleCloudData]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"sandbox/google_cloud/{jsonable_encoder(sandbox_id)}/dump",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DumpSandboxResponseGoogleCloudData,
                    parse_obj_as(
                        type_=DumpSandboxResponseGoogleCloudData,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawSandboxClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_sandbox(
        self, server_name: SandboxMcpServer, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CreateSandboxResponse]:
        """
        Acquire an idle sandbox instance for a specific MCP server. The sandbox will be marked as 'occupied'.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateSandboxResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateSandboxResponse,
                    parse_obj_as(
                        type_=CreateSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SandboxInfo]:
        """
        Retrieve detailed information about a specific sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SandboxInfo]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SandboxInfo,
                    parse_obj_as(
                        type_=SandboxInfo,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ReleaseSandboxResponse]:
        """
        Release an occupied sandbox back to idle state and marks the sandbox as available for reuse.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ReleaseSandboxResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ReleaseSandboxResponse,
                    parse_obj_as(
                        type_=ReleaseSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def reset_sandbox(
        self, server_name: SandboxMcpServer, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ResetSandboxResponse]:
        """
        Reset the sandbox to its initial empty state, clearing all data while maintaining the sandbox instance.

        Parameters
        ----------
        server_name : SandboxMcpServer
            The MCP server name

        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ResetSandboxResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/{jsonable_encoder(server_name)}/{jsonable_encoder(sandbox_id)}/reset",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ResetSandboxResponse,
                    parse_obj_as(
                        type_=ResetSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def initialize_sandbox(
        self,
        sandbox_id: str,
        *,
        datasets: typing.Optional[typing.Sequence[BigQueryDataset]] = OMIT,
        tables: typing.Optional[typing.Sequence[BigQueryTable]] = OMIT,
        buckets: typing.Optional[typing.Sequence[StorageBucket]] = OMIT,
        objects: typing.Optional[typing.Sequence[StorageObject]] = OMIT,
        log_entries: typing.Optional[typing.Sequence[LogEntry]] = OMIT,
        log_sinks: typing.Optional[typing.Sequence[LogSink]] = OMIT,
        log_buckets: typing.Optional[typing.Sequence[LogBucket]] = OMIT,
        instances: typing.Optional[typing.Sequence[ComputeInstance]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[InitializeSandboxResponse]:
        """
        Initialize the sandbox with google_cloud-specific data following the defined schema.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        datasets : typing.Optional[typing.Sequence[BigQueryDataset]]
            BigQuery datasets

        tables : typing.Optional[typing.Sequence[BigQueryTable]]
            BigQuery tables

        buckets : typing.Optional[typing.Sequence[StorageBucket]]
            Cloud Storage buckets

        objects : typing.Optional[typing.Sequence[StorageObject]]
            Cloud Storage objects

        log_entries : typing.Optional[typing.Sequence[LogEntry]]
            Log entries

        log_sinks : typing.Optional[typing.Sequence[LogSink]]
            Log sinks

        log_buckets : typing.Optional[typing.Sequence[LogBucket]]
            Log buckets

        instances : typing.Optional[typing.Sequence[ComputeInstance]]
            Compute Engine instances

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[InitializeSandboxResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/google_cloud/{jsonable_encoder(sandbox_id)}/initialize",
            method="POST",
            json={
                "datasets": convert_and_respect_annotation_metadata(
                    object_=datasets, annotation=typing.Sequence[BigQueryDataset], direction="write"
                ),
                "tables": convert_and_respect_annotation_metadata(
                    object_=tables, annotation=typing.Sequence[BigQueryTable], direction="write"
                ),
                "buckets": convert_and_respect_annotation_metadata(
                    object_=buckets, annotation=typing.Sequence[StorageBucket], direction="write"
                ),
                "objects": convert_and_respect_annotation_metadata(
                    object_=objects, annotation=typing.Sequence[StorageObject], direction="write"
                ),
                "logEntries": convert_and_respect_annotation_metadata(
                    object_=log_entries, annotation=typing.Sequence[LogEntry], direction="write"
                ),
                "logSinks": convert_and_respect_annotation_metadata(
                    object_=log_sinks, annotation=typing.Sequence[LogSink], direction="write"
                ),
                "logBuckets": convert_and_respect_annotation_metadata(
                    object_=log_buckets, annotation=typing.Sequence[LogBucket], direction="write"
                ),
                "instances": convert_and_respect_annotation_metadata(
                    object_=instances, annotation=typing.Sequence[ComputeInstance], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    InitializeSandboxResponse,
                    parse_obj_as(
                        type_=InitializeSandboxResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def dump_sandbox(
        self, sandbox_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DumpSandboxResponseGoogleCloudData]:
        """
        Export all data from the sandbox in the same format used for initialization.

        Parameters
        ----------
        sandbox_id : str
            The unique sandbox identifier

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DumpSandboxResponseGoogleCloudData]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"sandbox/google_cloud/{jsonable_encoder(sandbox_id)}/dump",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DumpSandboxResponseGoogleCloudData,
                    parse_obj_as(
                        type_=DumpSandboxResponseGoogleCloudData,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .google_docs_data import GoogleDocsData
from .sandbox_mcp_server import SandboxMcpServer


class DumpSandboxResponseGoogleDocsData(UniversalBaseModel):
    sandbox_id: str = pydantic.Field()
    """
    Sandbox identifier
    """

    server_name: SandboxMcpServer = pydantic.Field()
    """
    MCP server type
    """

    dumped_at: dt.datetime = pydantic.Field()
    """
    Timestamp of dump
    """

    data: GoogleDocsData = pydantic.Field()
    """
    Dumped sandbox data in server-specific format
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
